@@ -4,7 +4,6 @@ use crate::errors::Error;
 use crate::script::Script;
 use forc::test::{forc_build, BuildCommand};
 use fuel_asm::Opcode;
-use fuel_core::service::{Config, FuelService};
 use fuel_gql_client::client::FuelClient;
 use fuel_tx::{
     Address, Color, ContractId, Input, Output, Receipt, StorageSlot, Transaction, UtxoId, Witness,
@@ -187,7 +186,7 @@ impl Contract {
     /// For more details see `code_gen/functions_gen.rs`.
     pub fn method_hash<D: Detokenize>(
         fuel_client: &FuelClient,
-        compiled_contract: &CompiledContract,
+        contract_id: ContractId,
         signature: Selector,
         output_params: &[ParamType],
         args: &[Token],
@@ -205,8 +204,7 @@ impl Contract {
         let custom_inputs = args.iter().any(|t| matches!(t, Token::Struct(_)));
 
         Ok(ContractCall {
-            compiled_contract: compiled_contract.clone(),
-            contract_id: Self::compute_contract_id(compiled_contract),
+            contract_id,
             encoded_args,
             gas_price,
             gas_limit,
@@ -220,21 +218,6 @@ impl Contract {
         })
     }
 
-    /// Launches a local `fuel-core` network and deploys a contract to it.
-    /// If you want to deploy a contract against another network of
-    /// your choosing, use the `deploy` function instead.
-    pub async fn launch_and_deploy(
-        compiled_contract: &CompiledContract,
-    ) -> Result<(FuelClient, ContractId), Error> {
-        let srv = FuelService::new_node(Config::local_node()).await.unwrap();
-
-        let fuel_client = FuelClient::from(srv.bound_address);
-
-        let contract_id = Self::deploy(compiled_contract, &fuel_client).await?;
-
-        Ok((fuel_client, contract_id))
-    }
-
     /// Deploys a compiled contract to a running node
     pub async fn deploy(
         compiled_contract: &CompiledContract,
@@ -254,17 +237,20 @@ impl Contract {
         salt: Salt,
     ) -> Result<CompiledContract, Error> {
         let build_command = BuildCommand {
+            debug_outfile: None,
+            minify_json_abi: false,
             path: Some(project_path.into()),
             print_finalized_asm: false,
             print_intermediate_asm: false,
             binary_outfile: None,
             offline_mode: false,
+            output_directory: None,
             silent_mode: true,
             print_ir: false,
             use_ir: false,
         };
 
-        let raw =
+        let (raw, _) =
             forc_build::build(build_command).map_err(|message| Error::CompilationError(message))?;
 
         Ok(CompiledContract { salt, raw })
@@ -313,7 +299,6 @@ impl Contract {
 /// Helper for managing a transaction before submitting it to a node
 pub struct ContractCall<D> {
     pub fuel_client: FuelClient,
-    pub compiled_contract: CompiledContract,
     pub encoded_args: Vec<u8>,
     pub encoded_selector: Selector,
     pub contract_id: ContractId,
